# -*- coding: utf-8 -*-
from libs import base
from constants import *


class Xdr(object):
    """Xdr contains all information about xdr"""

    def __new__(cls, ip, port, infoport, cluster_id):

        if base.is_xdr_enabled(ip, infoport) is False or infoport == port:
            return {}
        return super(Xdr, cls).__new__(cls, ip, port, infoport, cluster_id)

    def __init__(self, ip, port, infoport, cluster_id):

        self._ip = ip
        self._port = port
        self._infoport = infoport
        self._cluster_id = cluster_id

    def get_statistics(self):

        self._statistics = base.get_xdr_statistics(self._ip, self._infoport)
        return self._statistics

    def get_subset_of_statistics(self, attrs=[]):

        subset = dict()

        stats = self.get_statistics()
        for attr in attrs:
            subset[attr] = stats.get(attr, NOT_SUPPORTED)
        return subset

    def get_statistic(self, attr):

        stats = self.get_statistics()
        return stats.get(attr, NOT_SUPPORTED)

    def get_configurations(self):

        self._configuration = base.get_node_configuration(self._ip, self._infoport)
        return self._configuration

    def get_subset_of_configurations(self, attrs=[]):

        subset = dict()
        configurations = self.get_configurations()

        for attr in attrs:
            subset[attr] = configurations.get(attr, NOT_SUPPORTED)
        return subset

    def get_configuration(self, attr):

        configurations = self.get_configurations()
        return configurations.get(attr, NOT_SUPPORTED)

    def update_configurations(self):

        self._configuration = base.get_node_configuration(self._ip, self._infoport, clear_cache=True)

    def set_configuration(self, parameter, value):

        status = base.set_xdr_configuration(self._ip, self._infoport, str(parameter), str(value))
        return status

    def set_configurations(self, edit_parameters):

        error_list = list()
        for key, value in list(edit_parameters.items()):
            if self.set_configuration(key, value) is False:
                error_list.append(key)
        self.update_configurations()

        return error_list

    def get_dc_statistics(self, dc):

        self._dc_statistics = base.get_dc_statistics(self._ip, self._infoport, dc)
        return self._statistics

    def get_subset_of_dc_statistics(self, attrs=[]):

        subset = dict()

        stats = self.get_dc_statistics()
        for attr in attrs:
            subset[attr] = stats.get(attr, NOT_SUPPORTED)
        return subset

    def get_dc_statistic(self, attr):

        stats = self.get_dc_statistics()
        return stats.get(attr, NOT_SUPPORTED)

    def get_dc_names(self):

        names = base.get_dc_names(self._ip, self._infoport)
        return names
